==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/component/impl/SatisfactionSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.component.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.component.ProvisionSet;
import io.ciera.tool.sql.ooaofooa.component.RequirementSet;
import io.ciera.tool.sql.ooaofooa.component.Satisfaction;
import io.ciera.tool.sql.ooaofooa.component.SatisfactionSet;
import io.ciera.tool.sql.ooaofooa.component.componentlibrary.ImportedProvisionInSatisfactionSet;
import io.ciera.tool.sql.ooaofooa.component.componentlibrary.ImportedRequirementSet;
import io.ciera.tool.sql.ooaofooa.component.componentlibrary.impl.ImportedProvisionInSatisfactionSetImpl;
import io.ciera.tool.sql.ooaofooa.component.componentlibrary.impl.ImportedRequirementSetImpl;
import io.ciera.tool.sql.ooaofooa.component.impl.ProvisionSetImpl;
import io.ciera.tool.sql.ooaofooa.component.impl.RequirementSetImpl;
import io.ciera.tool.sql.ooaofooa.instance.RuntimeChannelSet;
import io.ciera.tool.sql.ooaofooa.instance.impl.RuntimeChannelSetImpl;
import io.ciera.tool.sql.ooaofooa.packageableelement.PackageableElementSet;
import io.ciera.tool.sql.ooaofooa.packageableelement.impl.PackageableElementSetImpl;
import io.ciera.tool.sql.ooaofooa.persistenceassociations.SatisfactionInComponentSet;
import io.ciera.tool.sql.ooaofooa.persistenceassociations.impl.SatisfactionInComponentSetImpl;

import java.util.Arrays;
import java.util.List;


public class SatisfactionSetImpl extends InstanceSet<SatisfactionSet,Satisfaction> implements SatisfactionSet {

    // attributes
    @Override
    public void setId( UniqueId ref_Id ) throws XtumlException {
        for ( Satisfaction satisfaction : this ) satisfaction.setId( ref_Id );
    }
    @Override
    public void setLabel( String m_Label ) throws XtumlException {
        for ( Satisfaction satisfaction : this ) satisfaction.setLabel( m_Label );
    }
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( Satisfaction satisfaction : this ) satisfaction.setDescrip( m_Descrip );
    }
    @Override
    public void setProvision_Id( UniqueId ref_Provision_Id ) throws XtumlException {
        for ( Satisfaction satisfaction : this ) satisfaction.setProvision_Id( ref_Provision_Id );
    }
    @Override
    public void setRequirement_Id( UniqueId ref_Requirement_Id ) throws XtumlException {
        for ( Satisfaction satisfaction : this ) satisfaction.setRequirement_Id( ref_Requirement_Id );
    }


    // selections
    @Override
    public RuntimeChannelSet R2969_is_implemented_at_runtime_by_RuntimeChannel() throws XtumlException {
        RuntimeChannelSet runtimechannelset = new RuntimeChannelSetImpl();
        for ( Satisfaction satisfaction : this ) runtimechannelset.addAll( satisfaction.R2969_is_implemented_at_runtime_by_RuntimeChannel() );
        return runtimechannelset;
    }
    @Override
    public RequirementSet R4002_defines_required_satisfication_Requirement() throws XtumlException {
        RequirementSet requirementset = new RequirementSetImpl();
        for ( Satisfaction satisfaction : this ) requirementset.add( satisfaction.R4002_defines_required_satisfication_Requirement() );
        return requirementset;
    }
    @Override
    public ProvisionSet R4002_satisfies_Provision() throws XtumlException {
        ProvisionSet provisionset = new ProvisionSetImpl();
        for ( Satisfaction satisfaction : this ) provisionset.add( satisfaction.R4002_satisfies_Provision() );
        return provisionset;
    }
    @Override
    public ImportedProvisionInSatisfactionSet R4705_satisfaction_made_with_ImportedProvisionInSatisfaction() throws XtumlException {
        ImportedProvisionInSatisfactionSet importedprovisioninsatisfactionset = new ImportedProvisionInSatisfactionSetImpl();
        for ( Satisfaction satisfaction : this ) importedprovisioninsatisfactionset.add( satisfaction.R4705_satisfaction_made_with_ImportedProvisionInSatisfaction() );
        return importedprovisioninsatisfactionset;
    }
    @Override
    public ImportedRequirementSet R4706_satisfaction_made_with_ImportedRequirement() throws XtumlException {
        ImportedRequirementSet importedrequirementset = new ImportedRequirementSetImpl();
        for ( Satisfaction satisfaction : this ) importedrequirementset.add( satisfaction.R4706_satisfaction_made_with_ImportedRequirement() );
        return importedrequirementset;
    }
    @Override
    public PackageableElementSet R8001_is_a_PackageableElement() throws XtumlException {
        PackageableElementSet packageableelementset = new PackageableElementSetImpl();
        for ( Satisfaction satisfaction : this ) packageableelementset.add( satisfaction.R8001_is_a_PackageableElement() );
        return packageableelementset;
    }
    @Override
    public SatisfactionInComponentSet R9000_SatisfactionInComponent() throws XtumlException {
        SatisfactionInComponentSet satisfactionincomponentset = new SatisfactionInComponentSetImpl();
        for ( Satisfaction satisfaction : this ) satisfactionincomponentset.add( satisfaction.R9000_SatisfactionInComponent() );
        return satisfactionincomponentset;
    }


    @Override
    public Satisfaction nullElement() {
        return SatisfactionImpl.EMPTY_SATISFACTION;
    }

    @Override
    public SatisfactionSet emptySet() {
      return new SatisfactionSetImpl();
    }

    @Override
    public SatisfactionSet value() {
        return this;
    }

    @Override
    public List<Satisfaction> elements() {
        return Arrays.asList(toArray(new Satisfaction[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/component/impl/SatisfactionSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.component.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.component.ProvisionSet;
import io.ciera.tool.sql.ooaofooa.component.RequirementSet;
import io.ciera.tool.sql.ooaofooa.component.Satisfaction;
import io.ciera.tool.sql.ooaofooa.component.SatisfactionSet;
import io.ciera.tool.sql.ooaofooa.component.componentlibrary.ImportedProvisionInSatisfactionSet;
import io.ciera.tool.sql.ooaofooa.component.componentlibrary.ImportedRequirementSet;
import io.ciera.tool.sql.ooaofooa.component.componentlibrary.impl.ImportedProvisionInSatisfactionSetImpl;
import io.ciera.tool.sql.ooaofooa.component.componentlibrary.impl.ImportedRequirementSetImpl;
import io.ciera.tool.sql.ooaofooa.component.impl.ProvisionSetImpl;
import io.ciera.tool.sql.ooaofooa.component.impl.RequirementSetImpl;
import io.ciera.tool.sql.ooaofooa.instance.RuntimeChannelSet;
import io.ciera.tool.sql.ooaofooa.instance.impl.RuntimeChannelSetImpl;
import io.ciera.tool.sql.ooaofooa.packageableelement.PackageableElementSet;
import io.ciera.tool.sql.ooaofooa.packageableelement.impl.PackageableElementSetImpl;
import io.ciera.tool.sql.ooaofooa.persistenceassociations.SatisfactionInComponentSet;
import io.ciera.tool.sql.ooaofooa.persistenceassociations.impl.SatisfactionInComponentSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class SatisfactionSetImpl extends InstanceSet<SatisfactionSet,Satisfaction> implements SatisfactionSet {

    public SatisfactionSetImpl() {
    }

    public SatisfactionSetImpl(Comparator<? super Satisfaction> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setRequirement_Id( UniqueId ref_Requirement_Id ) throws XtumlException {
        for ( Satisfaction satisfaction : this ) satisfaction.setRequirement_Id( ref_Requirement_Id );
    }
    @Override
    public void setId( UniqueId ref_Id ) throws XtumlException {
        for ( Satisfaction satisfaction : this ) satisfaction.setId( ref_Id );
    }
    @Override
    public void setProvision_Id( UniqueId ref_Provision_Id ) throws XtumlException {
        for ( Satisfaction satisfaction : this ) satisfaction.setProvision_Id( ref_Provision_Id );
    }
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( Satisfaction satisfaction : this ) satisfaction.setDescrip( m_Descrip );
    }
    @Override
    public void setLabel( String m_Label ) throws XtumlException {
        for ( Satisfaction satisfaction : this ) satisfaction.setLabel( m_Label );
    }


    // selections
    @Override
    public RuntimeChannelSet R2969_is_implemented_at_runtime_by_RuntimeChannel() throws XtumlException {
        RuntimeChannelSet runtimechannelset = new RuntimeChannelSetImpl();
        for ( Satisfaction satisfaction : this ) runtimechannelset.addAll( satisfaction.R2969_is_implemented_at_runtime_by_RuntimeChannel() );
        return runtimechannelset;
    }
    @Override
    public RequirementSet R4002_defines_required_satisfication_Requirement() throws XtumlException {
        RequirementSet requirementset = new RequirementSetImpl();
        for ( Satisfaction satisfaction : this ) requirementset.add( satisfaction.R4002_defines_required_satisfication_Requirement() );
        return requirementset;
    }
    @Override
    public ProvisionSet R4002_satisfies_Provision() throws XtumlException {
        ProvisionSet provisionset = new ProvisionSetImpl();
        for ( Satisfaction satisfaction : this ) provisionset.add( satisfaction.R4002_satisfies_Provision() );
        return provisionset;
    }
    @Override
    public ImportedProvisionInSatisfactionSet R4705_satisfaction_made_with_ImportedProvisionInSatisfaction() throws XtumlException {
        ImportedProvisionInSatisfactionSet importedprovisioninsatisfactionset = new ImportedProvisionInSatisfactionSetImpl();
        for ( Satisfaction satisfaction : this ) importedprovisioninsatisfactionset.add( satisfaction.R4705_satisfaction_made_with_ImportedProvisionInSatisfaction() );
        return importedprovisioninsatisfactionset;
    }
    @Override
    public ImportedRequirementSet R4706_satisfaction_made_with_ImportedRequirement() throws XtumlException {
        ImportedRequirementSet importedrequirementset = new ImportedRequirementSetImpl();
        for ( Satisfaction satisfaction : this ) importedrequirementset.add( satisfaction.R4706_satisfaction_made_with_ImportedRequirement() );
        return importedrequirementset;
    }
    @Override
    public PackageableElementSet R8001_is_a_PackageableElement() throws XtumlException {
        PackageableElementSet packageableelementset = new PackageableElementSetImpl();
        for ( Satisfaction satisfaction : this ) packageableelementset.add( satisfaction.R8001_is_a_PackageableElement() );
        return packageableelementset;
    }
    @Override
    public SatisfactionInComponentSet R9000_SatisfactionInComponent() throws XtumlException {
        SatisfactionInComponentSet satisfactionincomponentset = new SatisfactionInComponentSetImpl();
        for ( Satisfaction satisfaction : this ) satisfactionincomponentset.add( satisfaction.R9000_SatisfactionInComponent() );
        return satisfactionincomponentset;
    }


    @Override
    public Satisfaction nullElement() {
        return SatisfactionImpl.EMPTY_SATISFACTION;
    }

    @Override
    public SatisfactionSet emptySet() {
      return new SatisfactionSetImpl();
    }

    @Override
    public SatisfactionSet emptySet(Comparator<? super Satisfaction> comp) {
      return new SatisfactionSetImpl(comp);
    }

    @Override
    public SatisfactionSet value() {
        return this;
    }

    @Override
    public List<Satisfaction> elements() {
        return Arrays.asList(toArray(new Satisfaction[0]));
    }

}
